@@ -282,6 +282,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       0xf00,
       { 7309,-1403,-519,-8474,16008,2622,-2434,2826,8064 } },
 
+    { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_Z30),
+      0,
+      0,
+      { 10339, -3822, -890, -4183, 12023, 2436, -671, 1638, 7049 } },
     { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_Z6),
       0,
       0,
@@ -492,6 +496,7 @@ const IfdFile::camera_ids_t NefFile::s_def[] = {
     { "NIKON D850", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D850) },
     { "NIKON D90", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D90) },
     { "NIKON Df", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_DF) },
+    { "NIKON Z 30", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_Z30) },
     { "NIKON Z 6", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_Z6) },
     { "NIKON Z 6_2", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_Z6_2) },
     { "NIKON Z 7", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_Z7) },
